Preparation of a proteomics analysis data set
prepare_proteomics_analysis_dataset.RdPreparation of a proteomics analysis data set
Arguments
- participant_data
A data frame of participant data
- protein_data
Protein data produced by
prepare_olink_data()orprepare_somascan_data().- protein_meta_data
Corresponding protein meta data produed by
prepare_olink_meta_data()orprepare_somascan_meta_data().- plate_correction
Type of plate correction to apply:
"none" (default)
"median-subcohort": For each protein, subtract the plate median (of subcohort values) and add the overall median (of subcohort values).
"mean-subcohort": For each protein, subtract the plate mean (of subcohort values) and add the overall mean (of subcohort values).
- scaling
Scaling to apply to values for each protein:
"none" (default)
"center-subcohort": Subtract the overall mean of subcohort values.
"scale-subcohort": Subtract the overall mean and divide by the sample standard deviation of subcohort values.
"center": Subtract the overall mean.
"scale": Subtract the overall mean and divide by the sample standard deviation.
"rint": Rank inverse normal transformation.
- id
Name of column used to join participant_data and protein_data. (Default: "csid")